==> hs-xmlhtml-0.2.0.2.tbz: lib/ghc-7.4.1/cabal/xmlhtml-0.2.0.2/register.sh <==
#!/bin/sh
echo 'name: xmlhtml
version: 0.2.0.2
id: xmlhtml-0.2.0.2-fddff920a2dff664c74fcdaf9763d9ba

license: BSD3
copyright:
maintainer: Chris Smith <cdsmith@gmail.com>
stability:
homepage:
package-url:
synopsis: XML parser and renderer with HTML 5 quirks mode
description: Contains renderers and parsers for both XML and HTML 5
             document fragments, which share data structures so that
             it'\''s easy to work with both.  Document fragments are bits
             of documents, which are not constrained by some of the
             high-level structure rules (in particular, they may
             contain more than one root element).
             .
             Note that this is not a compliant HTML 5 parser.  Rather,
             it is a parser for HTML 5 compliant documents.  It does not
             implement the HTML 5 parsing algorithm, and should
             generally be expected to perform correctly only on
             documents that you trust to conform to HTML 5.  This is
             not a suitable library for implementing web crawlers or
             other software that will be exposed to documents from
             outside sources.  The result is also not the HTML 5
             node structure, but rather something closer to the physical
             structure.  For example, omitted start tags are not
             inserted (and so, their corresponding end tags must also be
             omitted).
category: Text
author: Chris Smith <cdsmith@gmail.com>
exposed: True
exposed-modules: Text.XmlHtml Text.XmlHtml.Cursor
                 Text.Blaze.Renderer.XmlHtml
hidden-modules: Text.XmlHtml.Common Text.XmlHtml.TextParser
                Text.XmlHtml.XML.Parse Text.XmlHtml.XML.Render
                Text.XmlHtml.HTML.Meta Text.XmlHtml.HTML.Parse
                Text.XmlHtml.HTML.Render
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/xmlhtml-0.2.0.2
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/xmlhtml-0.2.0.2
              /usr/local/lib
hs-libraries: HSxmlhtml-0.2.0.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.5.0.0-1a022b3476300ed3e5bfdd46dd7221d0
         blaze-builder-0.3.1.0-b15df25e9ddf241eb83c0aad3bed9588
         blaze-html-0.5.0.0-901fbefff6b047b58a342a2c1c1fc359
         blaze-markup-0.5.1.0-09f3bcac3ad77b5578556536fd86b12b
         bytestring-0.9.2.1-e2bcd9910229fcb291a3a8dd6f79f7fe
         containers-0.4.2.1-7c54595400348f577b3b4a45691c5afd
         parsec-3.1.2-5d1caf26bfa3bdcc843000f0803b4975
         text-0.11.2.0-e612aa676a8fce1c637c16c9eb2bc9e2
         unordered-containers-0.2.1.0-0c2c5493b800a003d2156e3491c7d967
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/xmlhtml-0.2.0.2/html/xmlhtml.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/xmlhtml-0.2.0.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-xmlhtml-0.2.1.tbz: lib/ghc-7.4.2/cabal/xmlhtml-0.2.1/register.sh <==
#!/bin/sh
echo 'name: xmlhtml
version: 0.2.1
id: xmlhtml-0.2.1-644fd4312705acd0e570cdc5ce32d1e8

license: BSD3
copyright:
maintainer: Chris Smith <cdsmith@gmail.com>
stability:
homepage:
package-url:
synopsis: XML parser and renderer with HTML 5 quirks mode
description: Contains renderers and parsers for both XML and HTML 5
             document fragments, which share data structures so that
             it'\''s easy to work with both.  Document fragments are bits
             of documents, which are not constrained by some of the
             high-level structure rules (in particular, they may
             contain more than one root element).
             .
             Note that this is not a compliant HTML 5 parser.  Rather,
             it is a parser for HTML 5 compliant documents.  It does not
             implement the HTML 5 parsing algorithm, and should
             generally be expected to perform correctly only on
             documents that you trust to conform to HTML 5.  This is
             not a suitable library for implementing web crawlers or
             other software that will be exposed to documents from
             outside sources.  The result is also not the HTML 5
             node structure, but rather something closer to the physical
             structure.  For example, omitted start tags are not
             inserted (and so, their corresponding end tags must also be
             omitted).
category: Text
author: Chris Smith <cdsmith@gmail.com>
exposed: True
exposed-modules: Text.XmlHtml Text.XmlHtml.Cursor
                 Text.XmlHtml.HTML.Meta Text.Blaze.Renderer.XmlHtml
hidden-modules: Text.XmlHtml.Common Text.XmlHtml.TextParser
                Text.XmlHtml.XML.Parse Text.XmlHtml.XML.Render
                Text.XmlHtml.HTML.Parse Text.XmlHtml.HTML.Render
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/xmlhtml-0.2.1
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/xmlhtml-0.2.1
              /usr/local/lib
hs-libraries: HSxmlhtml-0.2.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.5.1.0-f58939ca866a8377999e7a71aa62d1d0
         blaze-builder-0.3.1.0-316b0e68f80ee32ff786c8cf5345f501
         blaze-html-0.6.0.0-266ca408369675ed72ec770dbbaf07ba
         blaze-markup-0.5.1.4-325465c17cbc5899fc09c8e2bb6610c3
         bytestring-0.9.2.1-4cc8a513193316dfe32ba33f47609c9d
         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
         parsec-3.1.3-5f7c2da354dce0be86cf682bae60efdd
         text-0.11.2.3-116e588a2afe9f305204001245768a0d
         unordered-containers-0.2.3.0-eea23be98f84f4fcc4f43b6a5a4ec815
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/xmlhtml-0.2.1/html/xmlhtml.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/xmlhtml-0.2.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
